=========
Amplitude
=========

Amplitude commands are used to create arbitrary time or frequency variations of load, displacement, and some interaction attributes throughout a step using step time or throughout an analysis using total time.

Create amplitudes
-----------------

In Mdb
~~~~~~

.. autoclass:: abaqus.Amplitude.AmplitudeModel.AmplitudeModel
    :members:

    .. autoclasstoc::


In Odb
~~~~~~

.. autoclass:: abaqus.Amplitude.AmplitudeOdb.AmplitudeOdb
    :members:

    .. autoclasstoc::


Object features
---------------

Amplitude
~~~~~~~~~

.. autoclass:: abaqus.Amplitude.Amplitude.Amplitude
    :members:

    .. autoclasstoc::

ActuatorAmplitude
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.ActuatorAmplitude.ActuatorAmplitude
    :members:

    .. autoclasstoc::

BaselineCorrection
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.BaselineCorrection.BaselineCorrection
    :members:

    .. autoclasstoc::

Correlation
~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.Correlation.Correlation
    :members:

    .. autoclasstoc::

DecayAmplitude
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.DecayAmplitude.DecayAmplitude
    :members:

    .. autoclasstoc::

EquallySpacedAmplitude
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.EquallySpacedAmplitude.EquallySpacedAmplitude
    :members:

    .. autoclasstoc::

ModulatedAmplitude
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.ModulatedAmplitude.ModulatedAmplitude
    :members:

    .. autoclasstoc::

PeriodicAmplitude
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.PeriodicAmplitude.PeriodicAmplitude
    :members:

    .. autoclasstoc::

PsdDefinition
~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.PsdDefinition.PsdDefinition
    :members:

    .. autoclasstoc::

SmoothStepAmplitude
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.SmoothStepAmplitude.SmoothStepAmplitude
    :members:

    .. autoclasstoc::

SolutionDependentAmplitude
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.SolutionDependentAmplitude.SolutionDependentAmplitude
    :members:

    .. autoclasstoc::

SpectrumAmplitude
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.SpectrumAmplitude.SpectrumAmplitude
    :members:

    .. autoclasstoc::

TabularAmplitude
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.TabularAmplitude.TabularAmplitude
    :members:

    .. autoclasstoc::
